Index: /FCKreleaser/trunk/_source/includes/fckpackager/fckjavascriptcompressor.inc
===================================================================
--- /FCKreleaser/trunk/_source/includes/fckpackager/fckjavascriptcompressor.inc	(revision 1976)
+++ /FCKreleaser/trunk/_source/includes/fckpackager/fckjavascriptcompressor.inc	(revision 1977)
@@ -72,7 +72,9 @@
 			' ', $script ) ;
 
-		// Concatenate lines that end with "}" using a ";" (except for "else" and "catch" cases).
+		// Concatenate lines that end with "}" using a ";", except for "else",
+		// "while", "catch" and "finally" cases, or when followed by, "'", ";",
+		// "}" or ")".
 		$script = preg_replace(
-			'/\s*}\s*[\n\r]+\s*(?!\s*(else|catch|}))/s',
+			'/\s*}\s*[\n\r]+\s*(?!\s*(else|catch|finally|while|[}\),;]))/s',
 			'};', $script ) ;
 
Index: /FCKreleaser/trunk/fckreleaser.php
===================================================================
--- /FCKreleaser/trunk/fckreleaser.php	(revision 1976)
+++ /FCKreleaser/trunk/fckreleaser.php	(revision 1977)
@@ -1,3 +1,3 @@
-#!/usr/bin/php -q
+﻿#!/usr/bin/php -q
 <?php
 /*
@@ -627,7 +627,9 @@
 			' ', $script ) ;
 
 		// Concatenate lines that end with "}" using a ";" (except for "else" and "catch" cases).
 		$script = preg_replace(
-			'/\s*}\s*[\n\r]+\s*(?!\s*(else|catch|}))/s',
+			'/\s*}\s*[\n\r]+\s*(?!\s*(else|catch|finally|while|[}\),;]))/s',
 			'};', $script ) ;
 
@@ -627,7 +627,9 @@
 			' ', $script ) ;
 
-		// Concatenate lines that end with "}" using a ";" (except for "else" and "catch" cases).
+		// Concatenate lines that end with "}" using a ";", except for "else",
+		// "while", "catch" and "finally" cases, or when followed by, "'", ";",
+		// "}" or ")".
 		$script = preg_replace(
